NXSConfigServer Tango Class Commands

NXSConfigServer Class Commands
Name | Input type | Output type | Level | Description
State | DEV_VOID | DEV_STATE | OPERATOR | This command gets the device state (stored in its device_state data member) and returns it to the caller.
Status | DEV_VOID | CONST_DEV_STRING | OPERATOR | This command gets the device status (stored in its device_status data member) and returns it to the caller.
Open | DEV_VOID | DEV_VOID | OPERATOR | Opens connection to the database
Close | DEV_VOID | DEV_VOID | OPERATOR | Closes connection into the database
Components | DEVVAR_STRINGARRAY | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of required components
Selections | DEVVAR_STRINGARRAY | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of required selections
InstantiatedComponents | DEVVAR_STRINGARRAY | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of required components
DataSources | DEVVAR_STRINGARRAY | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of required DataSources
AvailableComponents | DEV_VOID | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of available component names
AvailableSelections | DEV_VOID | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of available selection names
AvailableDataSources | DEV_VOID | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of available DataSource names
StoreSelection | DEV_STRING | DEV_VOID | OPERATOR | Stores the selection from XMLString
StoreComponent | DEV_STRING | DEV_VOID | OPERATOR | Stores the component from XMLString
StoreDataSource | DEV_STRING | DEV_VOID | OPERATOR | Stores the DataSource from XMLString
CreateConfiguration | DEVVAR_STRINGARRAY | DEV_VOID | OPERATOR | Creates the NDTS configuration script from the given components. The result is strored in XMLString
DeleteComponent | DEV_STRING | DEV_VOID | OPERATOR | Deletes the given component
DeleteSelection | DEV_STRING | DEV_VOID | OPERATOR | Deletes the given selection
DeleteDataSource | DEV_STRING | DEV_VOID | OPERATOR | Deletes the given datasource
SetComponentDataSources | DEV_STRING | DEV_VOID | OPERATOR | Sets component datasources according to given dictionary
SetMandatoryComponents | DEVVAR_STRINGARRAY | DEV_VOID | OPERATOR | Sets the mandatory components
MandatoryComponents | DEV_VOID | DEVVAR_STRINGARRAY | OPERATOR | Returns the mandatory components
UnsetMandatoryComponents | DEVVAR_STRINGARRAY | DEV_VOID | OPERATOR | Removes the given components from the mandatory components
ComponentDataSources | DEV_STRING | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of datasource names for a given component
ComponentsDataSources | DEVVAR_STRINGARRAY | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of datasource names for a given components
ComponentsVariables | DEVVAR_STRINGARRAY | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of variable names for a given components
ComponentVariables | DEV_STRING | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of variable names for a given component
Merge | DEVVAR_STRINGARRAY | DEV_STRING | OPERATOR | Merges give components
DependentComponents | DEVVAR_STRINGARRAY | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of dependent component names for a given components
InstantiatedDataSources | DEVVAR_STRINGARRAY | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of required datasources